@@ -1,20 +1,20 @@
 use std::{path::PathBuf, str::FromStr};
 
-use structopt::StructOpt;
+use clap::Parser;
 
-#[derive(Debug, StructOpt)]
-#[structopt(name = "convco", about = "Conventional commit tools")]
+#[derive(Debug, Parser)]
+#[clap(name = "convco", about = "Conventional commit tools", version)]
 pub struct Opt {
     /// Run as if convco was started in <path> instead of the current working directory.
-    #[structopt(short = "C", global = true)]
+    #[clap(short = 'C', global = true)]
     pub path: Option<PathBuf>,
-    #[structopt(short = "c", long = "config", global = true)]
+    #[clap(short = 'c', long = "config", global = true)]
     pub config: Option<PathBuf>,
-    #[structopt(subcommand)]
+    #[clap(subcommand)]
     pub cmd: Command,
 }
 
-#[derive(Debug, StructOpt)]
+#[derive(Debug, Parser)]
 pub enum Command {
     /// Verifies if all commits are conventional
     Check(CheckCommand),
@@ -26,120 +26,120 @@ pub enum Command {
     Commit(CommitCommand),
 }
 
-#[derive(Debug, StructOpt)]
+#[derive(Debug, Parser)]
 pub struct VersionCommand {
     /// Prefix used in front of the semantic version
-    #[structopt(short, long, default_value = "v")]
+    #[clap(short, long, default_value = "v")]
     pub prefix: String,
     /// Revision to show the version for
-    #[structopt(default_value = "HEAD")]
+    #[clap(default_value = "HEAD")]
     pub rev: String,
     /// Get the next version
-    #[structopt(short, long)]
+    #[clap(short, long)]
     pub bump: bool,
     /// Instead of printing out the bumped version, prints out one of: major, minor or patch
-    #[structopt(short, long, conflicts_with_all(&["major", "minor", "patch"]))]
+    #[clap(short, long, conflicts_with_all(&["major", "minor", "patch"]))]
     pub label: bool,
     /// Bump to a major release version, regardless of the conventional commits
-    #[structopt(long)]
+    #[clap(long)]
     pub major: bool,
     /// Bump to a minor release version, regardless of the conventional commits
-    #[structopt(long)]
+    #[clap(long)]
     pub minor: bool,
     /// Bump to a patch release version, regardless of the conventional commits
-    #[structopt(long)]
+    #[clap(long)]
     pub patch: bool,
 }
 
-#[derive(Debug, StructOpt)]
+#[derive(Debug, Parser)]
 pub struct CheckCommand {
     /// Start of the revwalk, can also be a commit range. Can be in the form `<commit>..<commit>`.
-    #[structopt(default_value = "HEAD")]
+    #[clap(default_value = "HEAD")]
     pub rev: String,
     /// Limit the number of commits to check.
-    #[structopt(short, long = "max-count")]
+    #[clap(short, long = "max-count")]
     pub number: Option<usize>,
 }
 
-#[derive(Debug, StructOpt)]
+#[derive(Debug, Parser)]
 pub struct ChangelogCommand {
     /// Prefix used in front of the semantic version.
-    #[structopt(short, long, default_value = "v")]
+    #[clap(short, long, default_value = "v")]
     pub prefix: String,
-    #[structopt(default_value = "HEAD")]
+    #[clap(default_value = "HEAD")]
     pub rev: String,
-    #[structopt(short, long)]
+    #[clap(short, long)]
     pub skip_empty: bool,
     /// Limits the number of version tags to add in the changelog
-    #[structopt(short, long)]
+    #[clap(short, long)]
     pub max_versions: Option<usize>,
 }
 
-#[derive(Debug, StructOpt)]
+#[derive(Debug, Parser)]
 pub struct CommitCommand {
     /// A bug fix
-    #[structopt(long,
+    #[clap(long,
         conflicts_with_all(&["feat", "build", "chore", "ci", "docs", "style", "refactor", "perf", "test", "type"]),
     )]
     pub fix: bool,
     /// A new feature
-    #[structopt(long,
+    #[clap(long,
         conflicts_with_all(&["fix", "build", "chore", "ci", "docs", "style", "refactor", "perf", "test", "type"]),
     )]
     pub feat: bool,
     /// Changes that affect the build system or external dependencies
-    #[structopt(long,
+    #[clap(long,
         conflicts_with_all(&["feat", "fix", "chore", "ci", "docs", "style", "refactor", "perf", "test", "type"]),
     )]
     pub build: bool,
     /// Other changes that don't modify src or test files
-    #[structopt(long,
+    #[clap(long,
         conflicts_with_all(&["feat", "fix", "build", "ci", "docs", "style", "refactor", "perf", "test", "type"]),
     )]
     pub chore: bool,
     /// Changes to CI configuration files and scripts
-    #[structopt(long,
+    #[clap(long,
         conflicts_with_all(&["feat", "fix", "build", "chore", "docs", "style", "refactor", "perf", "test", "type"]),
     )]
     pub ci: bool,
     /// Documentation only changes
-    #[structopt(long,
+    #[clap(long,
         conflicts_with_all(&["feat", "fix", "build", "chore", "ci", "style", "refactor", "perf", "test", "type"]),
     )]
     pub docs: bool,
     /// Changes that do not affect the meaning of the code (e.g. formatting)
-    #[structopt(long,
+    #[clap(long,
         conflicts_with_all(&["feat", "fix", "build", "chore", "ci", "docs", "refactor", "perf", "test", "type"]),
     )]
     pub style: bool,
     /// A code change that neither fixes a bug nor adds a feature
-    #[structopt(long,
+    #[clap(long,
         conflicts_with_all(&["feat", "fix", "build", "chore", "ci", "docs", "style", "perf", "test", "type"]),
     )]
     pub refactor: bool,
     /// A code change that improves performance
-    #[structopt(long,
+    #[clap(long,
         conflicts_with_all(&["feat", "fix", "build", "chore", "ci", "docs", "style", "refactor", "test", "type"]),
     )]
     pub perf: bool,
     /// Adding missing tests or correcting existing tests
-    #[structopt(long,
+    #[clap(long,
         conflicts_with_all(&["feat", "fix", "build", "chore", "ci", "docs", "style", "refactor", "perf", "type"]),
     )]
     pub test: bool,
     /// Specify your own commit type
-    #[structopt(short, long,
+    #[clap(short, long,
         conflicts_with_all(&["feat", "fix", "build", "chore", "ci", "docs", "style", "refactor", "perf", "test"]),
     )]
     pub r#type: Option<String>,
     /// Specifies the scope of the message
-    #[structopt(short, long)]
+    #[clap(short, long)]
     pub scope: Option<String>,
     /// The first message will be the description. Other -m options will be used as the body.
-    #[structopt(short, long)]
+    #[clap(short, long)]
     pub message: Vec<String>,
     /// Specify extra footers to the message
-    #[structopt(
+    #[clap(
         short,
         long,
         visible_alias = "trailer",
@@ -147,13 +147,13 @@ pub struct CommitCommand {
     )]
     pub footers: Vec<Footer>,
     /// Introduces a breaking change
-    #[structopt(long)]
+    #[clap(long)]
     pub breaking: bool,
     /// Interactive mode
-    #[structopt(long, short)]
+    #[clap(long, short)]
     pub interactive: bool,
     /// Extra arguments passed to the git commit command
-    #[structopt(last = true)]
+    #[clap(last = true)]
     pub extra_args: Vec<String>,
 }
 
